""" values file """
DevelopmentStatus__1_Planning = 'Development Status :: 1 - Planning'
DevelopmentStatus__2_Pre_Alpha = 'Development Status :: 2 - Pre-Alpha'
DevelopmentStatus__3_Alpha = 'Development Status :: 3 - Alpha'
DevelopmentStatus__4_Beta = 'Development Status :: 4 - Beta'
DevelopmentStatus__5_Production_Stable = 'Development Status :: 5 - Production/Stable'
DevelopmentStatus__6_Mature = 'Development Status :: 6 - Mature'
DevelopmentStatus__7_Inactive = 'Development Status :: 7 - Inactive'
Environment__Console = 'Environment :: Console'
Environment__Console__Curses = 'Environment :: Console :: Curses'
Environment__Console__Framebuffer = 'Environment :: Console :: Framebuffer'
Environment__Console__Newt = 'Environment :: Console :: Newt'
Environment__Console__svgalib = 'Environment :: Console :: svgalib'
Environment__GPU = 'Environment :: GPU'
Environment__GPU__NVIDIACUDA = 'Environment :: GPU :: NVIDIA CUDA'
Environment__GPU__NVIDIACUDA__10 = 'Environment :: GPU :: NVIDIA CUDA :: 1.0'
Environment__GPU__NVIDIACUDA__11 = 'Environment :: GPU :: NVIDIA CUDA :: 1.1'
Environment__GPU__NVIDIACUDA__20 = 'Environment :: GPU :: NVIDIA CUDA :: 2.0'
Environment__GPU__NVIDIACUDA__21 = 'Environment :: GPU :: NVIDIA CUDA :: 2.1'
Environment__GPU__NVIDIACUDA__22 = 'Environment :: GPU :: NVIDIA CUDA :: 2.2'
Environment__GPU__NVIDIACUDA__23 = 'Environment :: GPU :: NVIDIA CUDA :: 2.3'
Environment__GPU__NVIDIACUDA__30 = 'Environment :: GPU :: NVIDIA CUDA :: 3.0'
Environment__GPU__NVIDIACUDA__31 = 'Environment :: GPU :: NVIDIA CUDA :: 3.1'
Environment__GPU__NVIDIACUDA__32 = 'Environment :: GPU :: NVIDIA CUDA :: 3.2'
Environment__GPU__NVIDIACUDA__40 = 'Environment :: GPU :: NVIDIA CUDA :: 4.0'
Environment__GPU__NVIDIACUDA__41 = 'Environment :: GPU :: NVIDIA CUDA :: 4.1'
Environment__GPU__NVIDIACUDA__42 = 'Environment :: GPU :: NVIDIA CUDA :: 4.2'
Environment__GPU__NVIDIACUDA__50 = 'Environment :: GPU :: NVIDIA CUDA :: 5.0'
Environment__GPU__NVIDIACUDA__55 = 'Environment :: GPU :: NVIDIA CUDA :: 5.5'
Environment__GPU__NVIDIACUDA__60 = 'Environment :: GPU :: NVIDIA CUDA :: 6.0'
Environment__GPU__NVIDIACUDA__65 = 'Environment :: GPU :: NVIDIA CUDA :: 6.5'
Environment__GPU__NVIDIACUDA__70 = 'Environment :: GPU :: NVIDIA CUDA :: 7.0'
Environment__GPU__NVIDIACUDA__75 = 'Environment :: GPU :: NVIDIA CUDA :: 7.5'
Environment__GPU__NVIDIACUDA__80 = 'Environment :: GPU :: NVIDIA CUDA :: 8.0'
Environment__GPU__NVIDIACUDA__90 = 'Environment :: GPU :: NVIDIA CUDA :: 9.0'
Environment__GPU__NVIDIACUDA__91 = 'Environment :: GPU :: NVIDIA CUDA :: 9.1'
Environment__GPU__NVIDIACUDA__92 = 'Environment :: GPU :: NVIDIA CUDA :: 9.2'
Environment__GPU__NVIDIACUDA__100 = 'Environment :: GPU :: NVIDIA CUDA :: 10.0'
Environment__GPU__NVIDIACUDA__101 = 'Environment :: GPU :: NVIDIA CUDA :: 10.1'
Environment__GPU__NVIDIACUDA__102 = 'Environment :: GPU :: NVIDIA CUDA :: 10.2'
Environment__GPU__NVIDIACUDA__11 = 'Environment :: GPU :: NVIDIA CUDA :: 11'
Environment__GPU__NVIDIACUDA__110 = 'Environment :: GPU :: NVIDIA CUDA :: 11.0'
Environment__GPU__NVIDIACUDA__111 = 'Environment :: GPU :: NVIDIA CUDA :: 11.1'
Environment__GPU__NVIDIACUDA__112 = 'Environment :: GPU :: NVIDIA CUDA :: 11.2'
Environment__GPU__NVIDIACUDA__113 = 'Environment :: GPU :: NVIDIA CUDA :: 11.3'
Environment__GPU__NVIDIACUDA__114 = 'Environment :: GPU :: NVIDIA CUDA :: 11.4'
Environment__GPU__NVIDIACUDA__115 = 'Environment :: GPU :: NVIDIA CUDA :: 11.5'
Environment__GPU__NVIDIACUDA__116 = 'Environment :: GPU :: NVIDIA CUDA :: 11.6'
Environment__GPU__NVIDIACUDA__117 = 'Environment :: GPU :: NVIDIA CUDA :: 11.7'
Environment__GPU__NVIDIACUDA__118 = 'Environment :: GPU :: NVIDIA CUDA :: 11.8'
Environment__GPU__NVIDIACUDA__12 = 'Environment :: GPU :: NVIDIA CUDA :: 12'
Environment__GPU__NVIDIACUDA__12__120 = 'Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.0'
Environment__GPU__NVIDIACUDA__12__121 = 'Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.1'
Environment__GPU__NVIDIACUDA__12__122 = 'Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.2'
Environment__GPU__NVIDIACUDA__12__123 = 'Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.3'
Environment__GPU__NVIDIACUDA__12__124 = 'Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.4'
Environment__GPU__NVIDIACUDA__12__125 = 'Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.5'
Environment__GPU__NVIDIACUDA__12__126 = 'Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.6'
Environment__Handhelds_PDAs = 'Environment :: Handhelds/PDA\'s'
Environment__MacOSX = 'Environment :: MacOS X'
Environment__MacOSX__Aqua = 'Environment :: MacOS X :: Aqua'
Environment__MacOSX__Carbon = 'Environment :: MacOS X :: Carbon'
Environment__MacOSX__Cocoa = 'Environment :: MacOS X :: Cocoa'
Environment__NoInput_Output_Daemon_ = 'Environment :: No Input/Output (Daemon)'
Environment__OpenStack = 'Environment :: OpenStack'
Environment__OtherEnvironment = 'Environment :: Other Environment'
Environment__Plugins = 'Environment :: Plugins'
Environment__WebEnvironment = 'Environment :: Web Environment'
Environment__WebEnvironment__Buffet = 'Environment :: Web Environment :: Buffet'
Environment__WebEnvironment__Mozilla = 'Environment :: Web Environment :: Mozilla'
Environment__WebEnvironment__ToscaWidgets = 'Environment :: Web Environment :: ToscaWidgets'
Environment__WebAssembly = 'Environment :: WebAssembly'
Environment__WebAssembly__Emscripten = 'Environment :: WebAssembly :: Emscripten'
Environment__WebAssembly__WASI = 'Environment :: WebAssembly :: WASI'
Environment__Win32_MSWindows_ = 'Environment :: Win32 (MS Windows)'
Environment__X11Applications = 'Environment :: X11 Applications'
Environment__X11Applications__GTK = 'Environment :: X11 Applications :: GTK'
Environment__X11Applications__Gnome = 'Environment :: X11 Applications :: Gnome'
Environment__X11Applications__KDE = 'Environment :: X11 Applications :: KDE'
Environment__X11Applications__Qt = 'Environment :: X11 Applications :: Qt'
Framework__AWSCDK = 'Framework :: AWS CDK'
Framework__AWSCDK__1 = 'Framework :: AWS CDK :: 1'
Framework__AWSCDK__2 = 'Framework :: AWS CDK :: 2'
Framework__AiiDA = 'Framework :: AiiDA'
Framework__Ansible = 'Framework :: Ansible'
Framework__AnyIO = 'Framework :: AnyIO'
Framework__ApacheAirflow = 'Framework :: Apache Airflow'
Framework__ApacheAirflow__Provider = 'Framework :: Apache Airflow :: Provider'
Framework__AsyncIO = 'Framework :: AsyncIO'
Framework__BEAT = 'Framework :: BEAT'
Framework__BFG = 'Framework :: BFG'
Framework__Bob = 'Framework :: Bob'
Framework__Bottle = 'Framework :: Bottle'
Framework__Buildout = 'Framework :: Buildout'
Framework__Buildout__Extension = 'Framework :: Buildout :: Extension'
Framework__Buildout__Recipe = 'Framework :: Buildout :: Recipe'
Framework__CastleCMS = 'Framework :: CastleCMS'
Framework__CastleCMS__Theme = 'Framework :: CastleCMS :: Theme'
Framework__Celery = 'Framework :: Celery'
Framework__Chandler = 'Framework :: Chandler'
Framework__CherryPy = 'Framework :: CherryPy'
Framework__CubicWeb = 'Framework :: CubicWeb'
Framework__Dash = 'Framework :: Dash'
Framework__Datasette = 'Framework :: Datasette'
Framework__Django = 'Framework :: Django'
Framework__Django__1 = 'Framework :: Django :: 1'
Framework__Django__14 = 'Framework :: Django :: 1.4'
Framework__Django__15 = 'Framework :: Django :: 1.5'
Framework__Django__16 = 'Framework :: Django :: 1.6'
Framework__Django__17 = 'Framework :: Django :: 1.7'
Framework__Django__18 = 'Framework :: Django :: 1.8'
Framework__Django__19 = 'Framework :: Django :: 1.9'
Framework__Django__110 = 'Framework :: Django :: 1.10'
Framework__Django__111 = 'Framework :: Django :: 1.11'
Framework__Django__2 = 'Framework :: Django :: 2'
Framework__Django__20 = 'Framework :: Django :: 2.0'
Framework__Django__21 = 'Framework :: Django :: 2.1'
Framework__Django__22 = 'Framework :: Django :: 2.2'
Framework__Django__3 = 'Framework :: Django :: 3'
Framework__Django__30 = 'Framework :: Django :: 3.0'
Framework__Django__31 = 'Framework :: Django :: 3.1'
Framework__Django__32 = 'Framework :: Django :: 3.2'
Framework__Django__4 = 'Framework :: Django :: 4'
Framework__Django__40 = 'Framework :: Django :: 4.0'
Framework__Django__41 = 'Framework :: Django :: 4.1'
Framework__Django__42 = 'Framework :: Django :: 4.2'
Framework__Django__5 = 'Framework :: Django :: 5'
Framework__Django__50 = 'Framework :: Django :: 5.0'
Framework__Django__51 = 'Framework :: Django :: 5.1'
Framework__Django__52 = 'Framework :: Django :: 5.2'
Framework__DjangoCMS = 'Framework :: Django CMS'
Framework__DjangoCMS__34 = 'Framework :: Django CMS :: 3.4'
Framework__DjangoCMS__35 = 'Framework :: Django CMS :: 3.5'
Framework__DjangoCMS__36 = 'Framework :: Django CMS :: 3.6'
Framework__DjangoCMS__37 = 'Framework :: Django CMS :: 3.7'
Framework__DjangoCMS__38 = 'Framework :: Django CMS :: 3.8'
Framework__DjangoCMS__39 = 'Framework :: Django CMS :: 3.9'
Framework__DjangoCMS__310 = 'Framework :: Django CMS :: 3.10'
Framework__DjangoCMS__311 = 'Framework :: Django CMS :: 3.11'
Framework__DjangoCMS__40 = 'Framework :: Django CMS :: 4.0'
Framework__DjangoCMS__41 = 'Framework :: Django CMS :: 4.1'
Framework__DjangoCMS__50 = 'Framework :: Django CMS :: 5.0'
Framework__FastAPI = 'Framework :: FastAPI'
Framework__Flake8 = 'Framework :: Flake8'
Framework__Flask = 'Framework :: Flask'
Framework__Hatch = 'Framework :: Hatch'
Framework__Hypothesis = 'Framework :: Hypothesis'
Framework__IDLE = 'Framework :: IDLE'
Framework__IPython = 'Framework :: IPython'
Framework__Jupyter = 'Framework :: Jupyter'
Framework__Jupyter__JupyterLab = 'Framework :: Jupyter :: JupyterLab'
Framework__Jupyter__JupyterLab__1 = 'Framework :: Jupyter :: JupyterLab :: 1'
Framework__Jupyter__JupyterLab__2 = 'Framework :: Jupyter :: JupyterLab :: 2'
Framework__Jupyter__JupyterLab__3 = 'Framework :: Jupyter :: JupyterLab :: 3'
Framework__Jupyter__JupyterLab__4 = 'Framework :: Jupyter :: JupyterLab :: 4'
Framework__Jupyter__JupyterLab__Extensions = 'Framework :: Jupyter :: JupyterLab :: Extensions'
Framework__Jupyter__JupyterLab__Extensions__MimeRenderers = \
    'Framework :: Jupyter :: JupyterLab :: Extensions :: Mime Renderers'
Framework__Jupyter__JupyterLab__Extensions__Prebuilt = 'Framework :: Jupyter :: JupyterLab :: Extensions :: Prebuilt'
Framework__Jupyter__JupyterLab__Extensions__Themes = 'Framework :: Jupyter :: JupyterLab :: Extensions :: Themes'
Framework__Kedro = 'Framework :: Kedro'
Framework__Lektor = 'Framework :: Lektor'
Framework__Masonite = 'Framework :: Masonite'
Framework__Matplotlib = 'Framework :: Matplotlib'
Framework__MkDocs = 'Framework :: MkDocs'
Framework__Nengo = 'Framework :: Nengo'
Framework__Odoo = 'Framework :: Odoo'
Framework__Odoo__80 = 'Framework :: Odoo :: 8.0'
Framework__Odoo__90 = 'Framework :: Odoo :: 9.0'
Framework__Odoo__100 = 'Framework :: Odoo :: 10.0'
Framework__Odoo__110 = 'Framework :: Odoo :: 11.0'
Framework__Odoo__120 = 'Framework :: Odoo :: 12.0'
Framework__Odoo__130 = 'Framework :: Odoo :: 13.0'
Framework__Odoo__140 = 'Framework :: Odoo :: 14.0'
Framework__Odoo__150 = 'Framework :: Odoo :: 15.0'
Framework__Odoo__160 = 'Framework :: Odoo :: 16.0'
Framework__Odoo__170 = 'Framework :: Odoo :: 17.0'
Framework__Odoo__180 = 'Framework :: Odoo :: 18.0'
Framework__OpenTelemetry = 'Framework :: OpenTelemetry'
Framework__OpenTelemetry__Distros = 'Framework :: OpenTelemetry :: Distros'
Framework__OpenTelemetry__Exporters = 'Framework :: OpenTelemetry :: Exporters'
Framework__OpenTelemetry__Instrumentations = 'Framework :: OpenTelemetry :: Instrumentations'
Framework__Opps = 'Framework :: Opps'
Framework__Paste = 'Framework :: Paste'
Framework__Pelican = 'Framework :: Pelican'
Framework__Pelican__Plugins = 'Framework :: Pelican :: Plugins'
Framework__Pelican__Themes = 'Framework :: Pelican :: Themes'
Framework__Plone = 'Framework :: Plone'
Framework__Plone__32 = 'Framework :: Plone :: 3.2'
Framework__Plone__33 = 'Framework :: Plone :: 3.3'
Framework__Plone__40 = 'Framework :: Plone :: 4.0'
Framework__Plone__41 = 'Framework :: Plone :: 4.1'
Framework__Plone__42 = 'Framework :: Plone :: 4.2'
Framework__Plone__43 = 'Framework :: Plone :: 4.3'
Framework__Plone__50 = 'Framework :: Plone :: 5.0'
Framework__Plone__51 = 'Framework :: Plone :: 5.1'
Framework__Plone__52 = 'Framework :: Plone :: 5.2'
Framework__Plone__53 = 'Framework :: Plone :: 5.3'
Framework__Plone__60 = 'Framework :: Plone :: 6.0'
Framework__Plone__61 = 'Framework :: Plone :: 6.1'
Framework__Plone__62 = 'Framework :: Plone :: 6.2'
Framework__Plone__Addon = 'Framework :: Plone :: Addon'
Framework__Plone__Core = 'Framework :: Plone :: Core'
Framework__Plone__Distribution = 'Framework :: Plone :: Distribution'
Framework__Plone__Theme = 'Framework :: Plone :: Theme'
Framework__PySimpleGUI = 'Framework :: PySimpleGUI'
Framework__PySimpleGUI__4 = 'Framework :: PySimpleGUI :: 4'
Framework__PySimpleGUI__5 = 'Framework :: PySimpleGUI :: 5'
Framework__Pycsou = 'Framework :: Pycsou'
Framework__Pydantic = 'Framework :: Pydantic'
Framework__Pydantic__1 = 'Framework :: Pydantic :: 1'
Framework__Pydantic__2 = 'Framework :: Pydantic :: 2'
Framework__Pylons = 'Framework :: Pylons'
Framework__Pyodide = 'Framework :: Pyodide'
Framework__Pyramid = 'Framework :: Pyramid'
Framework__Pytest = 'Framework :: Pytest'
Framework__ReviewBoard = 'Framework :: Review Board'
Framework__RobotFramework = 'Framework :: Robot Framework'
Framework__RobotFramework__Library = 'Framework :: Robot Framework :: Library'
Framework__RobotFramework__Tool = 'Framework :: Robot Framework :: Tool'
Framework__Scrapy = 'Framework :: Scrapy'
Framework__SetuptoolsPlugin = 'Framework :: Setuptools Plugin'
Framework__Sphinx = 'Framework :: Sphinx'
Framework__Sphinx__Domain = 'Framework :: Sphinx :: Domain'
Framework__Sphinx__Extension = 'Framework :: Sphinx :: Extension'
Framework__Sphinx__Theme = 'Framework :: Sphinx :: Theme'
Framework__Trac = 'Framework :: Trac'
Framework__Trio = 'Framework :: Trio'
Framework__Tryton = 'Framework :: Tryton'
Framework__TurboGears = 'Framework :: TurboGears'
Framework__TurboGears__Applications = 'Framework :: TurboGears :: Applications'
Framework__TurboGears__Widgets = 'Framework :: TurboGears :: Widgets'
Framework__Twisted = 'Framework :: Twisted'
Framework__Wagtail = 'Framework :: Wagtail'
Framework__Wagtail__1 = 'Framework :: Wagtail :: 1'
Framework__Wagtail__2 = 'Framework :: Wagtail :: 2'
Framework__Wagtail__3 = 'Framework :: Wagtail :: 3'
Framework__Wagtail__4 = 'Framework :: Wagtail :: 4'
Framework__Wagtail__5 = 'Framework :: Wagtail :: 5'
Framework__Wagtail__6 = 'Framework :: Wagtail :: 6'
Framework__Wagtail__7 = 'Framework :: Wagtail :: 7'
Framework__ZODB = 'Framework :: ZODB'
Framework__Zope = 'Framework :: Zope'
Framework__Zope2 = 'Framework :: Zope2'
Framework__Zope3 = 'Framework :: Zope3'
Framework__Zope__2 = 'Framework :: Zope :: 2'
Framework__Zope__3 = 'Framework :: Zope :: 3'
Framework__Zope__4 = 'Framework :: Zope :: 4'
Framework__Zope__5 = 'Framework :: Zope :: 5'
Framework__aiohttp = 'Framework :: aiohttp'
Framework__cocotb = 'Framework :: cocotb'
Framework__napari = 'Framework :: napari'
Framework__tox = 'Framework :: tox'
IntendedAudience__CustomerService = 'Intended Audience :: Customer Service'
IntendedAudience__Developers = 'Intended Audience :: Developers'
IntendedAudience__Education = 'Intended Audience :: Education'
IntendedAudience__EndUsers_Desktop = 'Intended Audience :: End Users/Desktop'
IntendedAudience__FinancialandInsuranceIndustry = 'Intended Audience :: Financial and Insurance Industry'
IntendedAudience__HealthcareIndustry = 'Intended Audience :: Healthcare Industry'
IntendedAudience__InformationTechnology = 'Intended Audience :: Information Technology'
IntendedAudience__LegalIndustry = 'Intended Audience :: Legal Industry'
IntendedAudience__Manufacturing = 'Intended Audience :: Manufacturing'
IntendedAudience__OtherAudience = 'Intended Audience :: Other Audience'
IntendedAudience__Religion = 'Intended Audience :: Religion'
IntendedAudience__Science_Research = 'Intended Audience :: Science/Research'
IntendedAudience__SystemAdministrators = 'Intended Audience :: System Administrators'
IntendedAudience__TelecommunicationsIndustry = 'Intended Audience :: Telecommunications Industry'
License__AladdinFreePublicLicense_AFPL_ = 'License :: Aladdin Free Public License (AFPL)'
License__CC010Universal_CC010_PublicDomainDedication = \
    'License :: CC0 1.0 Universal (CC0 1.0) Public Domain Dedication'
License__CeCILL_BFreeSoftwareLicenseAgreement_CECILL_B_ = \
    'License :: CeCILL-B Free Software License Agreement (CECILL-B)'
License__CeCILL_CFreeSoftwareLicenseAgreement_CECILL_C_ = \
    'License :: CeCILL-C Free Software License Agreement (CECILL-C)'
License__DFSGapproved = 'License :: DFSG approved'
License__EiffelForumLicense_EFL_ = 'License :: Eiffel Forum License (EFL)'
License__FreeForEducationalUse = 'License :: Free For Educational Use'
License__FreeForHomeUse = 'License :: Free For Home Use'
License__FreeToUseButRestricted = 'License :: Free To Use But Restricted'
License__Freefornon_commercialuse = 'License :: Free for non-commercial use'
License__FreelyDistributable = 'License :: Freely Distributable'
License__Freeware = 'License :: Freeware'
License__GUSTFontLicense10 = 'License :: GUST Font License 1.0'
License__GUSTFontLicense2006_09_30 = 'License :: GUST Font License 2006-09-30'
License__NetscapePublicLicense_NPL_ = 'License :: Netscape Public License (NPL)'
License__NokiaOpenSourceLicense_NOKOS_ = 'License :: Nokia Open Source License (NOKOS)'
License__OSIApproved = 'License :: OSI Approved'
License__OSIApproved__AcademicFreeLicense_AFL_ = 'License :: OSI Approved :: Academic Free License (AFL)'
License__OSIApproved__ApacheSoftwareLicense = 'License :: OSI Approved :: Apache Software License'
License__OSIApproved__ApplePublicSourceLicense = 'License :: OSI Approved :: Apple Public Source License'
License__OSIApproved__ArtisticLicense = 'License :: OSI Approved :: Artistic License'
License__OSIApproved__AttributionAssuranceLicense = 'License :: OSI Approved :: Attribution Assurance License'
License__OSIApproved__BSDLicense = 'License :: OSI Approved :: BSD License'
License__OSIApproved__BlueOakModelLicense_BlueOak_100_ = \
    'License :: OSI Approved :: Blue Oak Model License (BlueOak-1.0.0)'
License__OSIApproved__BoostSoftwareLicense10_BSL_10_ = \
    'License :: OSI Approved :: Boost Software License 1.0 (BSL-1.0)'
License__OSIApproved__CEACNRSInriaLogicielLibreLicenseversion21_CeCILL_21_ = \
    'License :: OSI Approved :: CEA CNRS Inria Logiciel Libre License, version 2.1 (CeCILL-2.1)'
License__OSIApproved__CMULicense_MIT_CMU_ = 'License :: OSI Approved :: CMU License (MIT-CMU)'
License__OSIApproved__CommonDevelopmentandDistributionLicense10_CDDL_10_ = \
    'License :: OSI Approved :: Common Development and Distribution License 1.0 (CDDL-1.0)'
License__OSIApproved__CommonPublicLicense = 'License :: OSI Approved :: Common Public License'
License__OSIApproved__EclipsePublicLicense10_EPL_10_ = \
    'License :: OSI Approved :: Eclipse Public License 1.0 (EPL-1.0)'
License__OSIApproved__EclipsePublicLicense20_EPL_20_ = \
    'License :: OSI Approved :: Eclipse Public License 2.0 (EPL-2.0)'
License__OSIApproved__EducationalCommunityLicenseVersion20_ECL_20_ = \
    'License :: OSI Approved :: Educational Community License, Version 2.0 (ECL-2.0)'
License__OSIApproved__EiffelForumLicense = 'License :: OSI Approved :: Eiffel Forum License'
License__OSIApproved__EuropeanUnionPublicLicence10_EUPL10_ = \
    'License :: OSI Approved :: European Union Public Licence 1.0 (EUPL 1.0)'
License__OSIApproved__EuropeanUnionPublicLicence11_EUPL11_ = \
    'License :: OSI Approved :: European Union Public Licence 1.1 (EUPL 1.1)'
License__OSIApproved__EuropeanUnionPublicLicence12_EUPL12_ = \
    'License :: OSI Approved :: European Union Public Licence 1.2 (EUPL 1.2)'
License__OSIApproved__GNUAfferoGeneralPublicLicensev3 = \
    'License :: OSI Approved :: GNU Affero General Public License v3'
License__OSIApproved__GNUAfferoGeneralPublicLicensev3orlater_AGPLv3__ = \
    'License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)'
License__OSIApproved__GNUFreeDocumentationLicense_FDL_ = \
    'License :: OSI Approved :: GNU Free Documentation License (FDL)'
License__OSIApproved__GNUGeneralPublicLicense_GPL_ = 'License :: OSI Approved :: GNU General Public License (GPL)'
License__OSIApproved__GNUGeneralPublicLicensev2_GPLv2_ = \
    'License :: OSI Approved :: GNU General Public License v2 (GPLv2)'
License__OSIApproved__GNUGeneralPublicLicensev2orlater_GPLv2__ = \
    'License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)'
License__OSIApproved__GNUGeneralPublicLicensev3_GPLv3_ = \
    'License :: OSI Approved :: GNU General Public License v3 (GPLv3)'
License__OSIApproved__GNUGeneralPublicLicensev3orlater_GPLv3__ = \
    'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)'
License__OSIApproved__GNULesserGeneralPublicLicensev2_LGPLv2_ = \
    'License :: OSI Approved :: GNU Lesser General Public License v2 (LGPLv2)'
License__OSIApproved__GNULesserGeneralPublicLicensev2orlater_LGPLv2__ = \
    'License :: OSI Approved :: GNU Lesser General Public License v2 or later (LGPLv2+)'
License__OSIApproved__GNULesserGeneralPublicLicensev3_LGPLv3_ = \
    'License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)'
License__OSIApproved__GNULesserGeneralPublicLicensev3orlater_LGPLv3__ = \
    'License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)'
License__OSIApproved__GNULibraryorLesserGeneralPublicLicense_LGPL_ = \
    'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)'
License__OSIApproved__HistoricalPermissionNoticeandDisclaimer_HPND_ = \
    'License :: OSI Approved :: Historical Permission Notice and Disclaimer (HPND)'
License__OSIApproved__IBMPublicLicense = 'License :: OSI Approved :: IBM Public License'
License__OSIApproved__ISCLicense_ISCL_ = 'License :: OSI Approved :: ISC License (ISCL)'
License__OSIApproved__MITLicense = 'License :: OSI Approved :: MIT License'
License__OSIApproved__MITNoAttributionLicense_MIT_0_ = 'License :: OSI Approved :: MIT No Attribution License (MIT-0)'
License__OSIApproved__MirOSLicense_MirOS_ = 'License :: OSI Approved :: MirOS License (MirOS)'
License__OSIApproved__MotosotoLicense = 'License :: OSI Approved :: Motosoto License'
License__OSIApproved__MozillaPublicLicense10_MPL_ = 'License :: OSI Approved :: Mozilla Public License 1.0 (MPL)'
License__OSIApproved__MozillaPublicLicense11_MPL11_ = \
    'License :: OSI Approved :: Mozilla Public License 1.1 (MPL 1.1)'
License__OSIApproved__MozillaPublicLicense20_MPL20_ = \
    'License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)'
License__OSIApproved__MulanPermissiveSoftwareLicensev2_MulanPSL_20_ = \
    'License :: OSI Approved :: Mulan Permissive Software License v2 (MulanPSL-2.0)'
License__OSIApproved__NASAOpenSourceAgreementv13_NASA_13_ = \
    'License :: OSI Approved :: NASA Open Source Agreement v1.3 (NASA-1.3)'
License__OSIApproved__NethackGeneralPublicLicense = 'License :: OSI Approved :: Nethack General Public License'
License__OSIApproved__NokiaOpenSourceLicense = 'License :: OSI Approved :: Nokia Open Source License'
License__OSIApproved__OpenGroupTestSuiteLicense = 'License :: OSI Approved :: Open Group Test Suite License'
License__OSIApproved__OpenSoftwareLicense30_OSL_30_ = 'License :: OSI Approved :: Open Software License 3.0 (OSL-3.0)'
License__OSIApproved__PostgreSQLLicense = 'License :: OSI Approved :: PostgreSQL License'
License__OSIApproved__PythonLicense_CNRIPythonLicense_ = \
    'License :: OSI Approved :: Python License (CNRI Python License)'
License__OSIApproved__PythonSoftwareFoundationLicense = \
    'License :: OSI Approved :: Python Software Foundation License'
License__OSIApproved__QtPublicLicense_QPL_ = 'License :: OSI Approved :: Qt Public License (QPL)'
License__OSIApproved__RicohSourceCodePublicLicense = 'License :: OSI Approved :: Ricoh Source Code Public License'
License__OSIApproved__SILOpenFontLicense11_OFL_11_ = 'License :: OSI Approved :: SIL Open Font License 1.1 (OFL-1.1)'
License__OSIApproved__SleepycatLicense = 'License :: OSI Approved :: Sleepycat License'
License__OSIApproved__SunPublicLicense = 'License :: OSI Approved :: Sun Public License'
License__OSIApproved__TheUnlicense_Unlicense_ = 'License :: OSI Approved :: The Unlicense (Unlicense)'
License__OSIApproved__UniversalPermissiveLicense_UPL_ = \
    'License :: OSI Approved :: Universal Permissive License (UPL)'
License__OSIApproved__UniversityofIllinois_NCSAOpenSourceLicense = \
    'License :: OSI Approved :: University of Illinois/NCSA Open Source License'
License__OSIApproved__VovidaSoftwareLicense10 = 'License :: OSI Approved :: Vovida Software License 1.0'
License__OSIApproved__W3CLicense = 'License :: OSI Approved :: W3C License'
License__OSIApproved__Zero_ClauseBSD_0BSD_ = 'License :: OSI Approved :: Zero-Clause BSD (0BSD)'
License__OSIApproved__ZopePublicLicense = 'License :: OSI Approved :: Zope Public License'
License__OSIApproved__zlib_libpngLicense = 'License :: OSI Approved :: zlib/libpng License'
License__Other_ProprietaryLicense = 'License :: Other/Proprietary License'
License__PublicDomain = 'License :: Public Domain'
License__RepozePublicLicense = 'License :: Repoze Public License'
NaturalLanguage__Afrikaans = 'Natural Language :: Afrikaans'
NaturalLanguage__Arabic = 'Natural Language :: Arabic'
NaturalLanguage__Basque = 'Natural Language :: Basque'
NaturalLanguage__Bengali = 'Natural Language :: Bengali'
NaturalLanguage__Bosnian = 'Natural Language :: Bosnian'
NaturalLanguage__Bulgarian = 'Natural Language :: Bulgarian'
NaturalLanguage__Cantonese = 'Natural Language :: Cantonese'
NaturalLanguage__Catalan = 'Natural Language :: Catalan'
NaturalLanguage__Catalan_Valencian_ = 'Natural Language :: Catalan (Valencian)'
NaturalLanguage__Chinese_Simplified_ = 'Natural Language :: Chinese (Simplified)'
NaturalLanguage__Chinese_Traditional_ = 'Natural Language :: Chinese (Traditional)'
NaturalLanguage__Croatian = 'Natural Language :: Croatian'
NaturalLanguage__Czech = 'Natural Language :: Czech'
NaturalLanguage__Danish = 'Natural Language :: Danish'
NaturalLanguage__Dutch = 'Natural Language :: Dutch'
NaturalLanguage__English = 'Natural Language :: English'
NaturalLanguage__Esperanto = 'Natural Language :: Esperanto'
NaturalLanguage__Finnish = 'Natural Language :: Finnish'
NaturalLanguage__French = 'Natural Language :: French'
NaturalLanguage__Galician = 'Natural Language :: Galician'
NaturalLanguage__Georgian = 'Natural Language :: Georgian'
NaturalLanguage__German = 'Natural Language :: German'
NaturalLanguage__Greek = 'Natural Language :: Greek'
NaturalLanguage__Hebrew = 'Natural Language :: Hebrew'
NaturalLanguage__Hindi = 'Natural Language :: Hindi'
NaturalLanguage__Hungarian = 'Natural Language :: Hungarian'
NaturalLanguage__Icelandic = 'Natural Language :: Icelandic'
NaturalLanguage__Indonesian = 'Natural Language :: Indonesian'
NaturalLanguage__Irish = 'Natural Language :: Irish'
NaturalLanguage__Italian = 'Natural Language :: Italian'
NaturalLanguage__Japanese = 'Natural Language :: Japanese'
NaturalLanguage__Javanese = 'Natural Language :: Javanese'
NaturalLanguage__Korean = 'Natural Language :: Korean'
NaturalLanguage__Latin = 'Natural Language :: Latin'
NaturalLanguage__Latvian = 'Natural Language :: Latvian'
NaturalLanguage__Lithuanian = 'Natural Language :: Lithuanian'
NaturalLanguage__Macedonian = 'Natural Language :: Macedonian'
NaturalLanguage__Malay = 'Natural Language :: Malay'
NaturalLanguage__Marathi = 'Natural Language :: Marathi'
NaturalLanguage__Nepali = 'Natural Language :: Nepali'
NaturalLanguage__Norwegian = 'Natural Language :: Norwegian'
NaturalLanguage__Panjabi = 'Natural Language :: Panjabi'
NaturalLanguage__Persian = 'Natural Language :: Persian'
NaturalLanguage__Polish = 'Natural Language :: Polish'
NaturalLanguage__Portuguese = 'Natural Language :: Portuguese'
NaturalLanguage__Portuguese_Brazilian_ = 'Natural Language :: Portuguese (Brazilian)'
NaturalLanguage__Romanian = 'Natural Language :: Romanian'
NaturalLanguage__Russian = 'Natural Language :: Russian'
NaturalLanguage__Serbian = 'Natural Language :: Serbian'
NaturalLanguage__Slovak = 'Natural Language :: Slovak'
NaturalLanguage__Slovenian = 'Natural Language :: Slovenian'
NaturalLanguage__Spanish = 'Natural Language :: Spanish'
NaturalLanguage__Swedish = 'Natural Language :: Swedish'
NaturalLanguage__Tamil = 'Natural Language :: Tamil'
NaturalLanguage__Telugu = 'Natural Language :: Telugu'
NaturalLanguage__Thai = 'Natural Language :: Thai'
NaturalLanguage__Tibetan = 'Natural Language :: Tibetan'
NaturalLanguage__Turkish = 'Natural Language :: Turkish'
NaturalLanguage__Ukrainian = 'Natural Language :: Ukrainian'
NaturalLanguage__Urdu = 'Natural Language :: Urdu'
NaturalLanguage__Vietnamese = 'Natural Language :: Vietnamese'
OperatingSystem__Android = 'Operating System :: Android'
OperatingSystem__BeOS = 'Operating System :: BeOS'
OperatingSystem__MacOS = 'Operating System :: MacOS'
OperatingSystem__MacOS__MacOS9 = 'Operating System :: MacOS :: MacOS 9'
OperatingSystem__MacOS__MacOSX = 'Operating System :: MacOS :: MacOS X'
OperatingSystem__Microsoft = 'Operating System :: Microsoft'
OperatingSystem__Microsoft__MS_DOS = 'Operating System :: Microsoft :: MS-DOS'
OperatingSystem__Microsoft__Windows = 'Operating System :: Microsoft :: Windows'
OperatingSystem__Microsoft__Windows__Windows31orEarlier = \
    'Operating System :: Microsoft :: Windows :: Windows 3.1 or Earlier'
OperatingSystem__Microsoft__Windows__Windows7 = 'Operating System :: Microsoft :: Windows :: Windows 7'
OperatingSystem__Microsoft__Windows__Windows8 = 'Operating System :: Microsoft :: Windows :: Windows 8'
OperatingSystem__Microsoft__Windows__Windows81 = 'Operating System :: Microsoft :: Windows :: Windows 8.1'
OperatingSystem__Microsoft__Windows__Windows10 = 'Operating System :: Microsoft :: Windows :: Windows 10'
OperatingSystem__Microsoft__Windows__Windows11 = 'Operating System :: Microsoft :: Windows :: Windows 11'
OperatingSystem__Microsoft__Windows__Windows95_98_2000 = \
    'Operating System :: Microsoft :: Windows :: Windows 95/98/2000'
OperatingSystem__Microsoft__Windows__WindowsCE = 'Operating System :: Microsoft :: Windows :: Windows CE'
OperatingSystem__Microsoft__Windows__WindowsNT_2000 = 'Operating System :: Microsoft :: Windows :: Windows NT/2000'
OperatingSystem__Microsoft__Windows__WindowsServer2003 = \
    'Operating System :: Microsoft :: Windows :: Windows Server 2003'
OperatingSystem__Microsoft__Windows__WindowsServer2008 = \
    'Operating System :: Microsoft :: Windows :: Windows Server 2008'
OperatingSystem__Microsoft__Windows__WindowsVista = 'Operating System :: Microsoft :: Windows :: Windows Vista'
OperatingSystem__Microsoft__Windows__WindowsXP = 'Operating System :: Microsoft :: Windows :: Windows XP'
OperatingSystem__OSIndependent = 'Operating System :: OS Independent'
OperatingSystem__OS_2 = 'Operating System :: OS/2'
OperatingSystem__OtherOS = 'Operating System :: Other OS'
OperatingSystem__PDASystems = 'Operating System :: PDA Systems'
OperatingSystem__POSIX = 'Operating System :: POSIX'
OperatingSystem__POSIX__AIX = 'Operating System :: POSIX :: AIX'
OperatingSystem__POSIX__BSD = 'Operating System :: POSIX :: BSD'
OperatingSystem__POSIX__BSD__BSD_OS = 'Operating System :: POSIX :: BSD :: BSD/OS'
OperatingSystem__POSIX__BSD__FreeBSD = 'Operating System :: POSIX :: BSD :: FreeBSD'
OperatingSystem__POSIX__BSD__NetBSD = 'Operating System :: POSIX :: BSD :: NetBSD'
OperatingSystem__POSIX__BSD__OpenBSD = 'Operating System :: POSIX :: BSD :: OpenBSD'
OperatingSystem__POSIX__GNUHurd = 'Operating System :: POSIX :: GNU Hurd'
OperatingSystem__POSIX__HP_UX = 'Operating System :: POSIX :: HP-UX'
OperatingSystem__POSIX__IRIX = 'Operating System :: POSIX :: IRIX'
OperatingSystem__POSIX__Linux = 'Operating System :: POSIX :: Linux'
OperatingSystem__POSIX__Other = 'Operating System :: POSIX :: Other'
OperatingSystem__POSIX__SCO = 'Operating System :: POSIX :: SCO'
OperatingSystem__POSIX__SunOS_Solaris = 'Operating System :: POSIX :: SunOS/Solaris'
OperatingSystem__PalmOS = 'Operating System :: PalmOS'
OperatingSystem__RISCOS = 'Operating System :: RISC OS'
OperatingSystem__Unix = 'Operating System :: Unix'
OperatingSystem__iOS = 'Operating System :: iOS'
ProgrammingLanguage__APL = 'Programming Language :: APL'
ProgrammingLanguage__ASP = 'Programming Language :: ASP'
ProgrammingLanguage__Ada = 'Programming Language :: Ada'
ProgrammingLanguage__Assembly = 'Programming Language :: Assembly'
ProgrammingLanguage__Awk = 'Programming Language :: Awk'
ProgrammingLanguage__Basic = 'Programming Language :: Basic'
ProgrammingLanguage__C = 'Programming Language :: C'
ProgrammingLanguage__Csharp = 'Programming Language :: C#'
ProgrammingLanguage__C__ = 'Programming Language :: C++'
ProgrammingLanguage__ColdFusion = 'Programming Language :: Cold Fusion'
ProgrammingLanguage__Cython = 'Programming Language :: Cython'
ProgrammingLanguage__D = 'Programming Language :: D'
ProgrammingLanguage__Delphi_Kylix = 'Programming Language :: Delphi/Kylix'
ProgrammingLanguage__Dylan = 'Programming Language :: Dylan'
ProgrammingLanguage__Eiffel = 'Programming Language :: Eiffel'
ProgrammingLanguage__Emacs_Lisp = 'Programming Language :: Emacs-Lisp'
ProgrammingLanguage__Erlang = 'Programming Language :: Erlang'
ProgrammingLanguage__Euler = 'Programming Language :: Euler'
ProgrammingLanguage__Euphoria = 'Programming Language :: Euphoria'
ProgrammingLanguage__Fsharp = 'Programming Language :: F#'
ProgrammingLanguage__Forth = 'Programming Language :: Forth'
ProgrammingLanguage__Fortran = 'Programming Language :: Fortran'
ProgrammingLanguage__Go = 'Programming Language :: Go'
ProgrammingLanguage__Haskell = 'Programming Language :: Haskell'
ProgrammingLanguage__Hy = 'Programming Language :: Hy'
ProgrammingLanguage__Java = 'Programming Language :: Java'
ProgrammingLanguage__JavaScript = 'Programming Language :: JavaScript'
ProgrammingLanguage__Kotlin = 'Programming Language :: Kotlin'
ProgrammingLanguage__Lisp = 'Programming Language :: Lisp'
ProgrammingLanguage__Logo = 'Programming Language :: Logo'
ProgrammingLanguage__Lua = 'Programming Language :: Lua'
ProgrammingLanguage__ML = 'Programming Language :: ML'
ProgrammingLanguage__Modula = 'Programming Language :: Modula'
ProgrammingLanguage__OCaml = 'Programming Language :: OCaml'
ProgrammingLanguage__ObjectPascal = 'Programming Language :: Object Pascal'
ProgrammingLanguage__ObjectiveC = 'Programming Language :: Objective C'
ProgrammingLanguage__Other = 'Programming Language :: Other'
ProgrammingLanguage__OtherScriptingEngines = 'Programming Language :: Other Scripting Engines'
ProgrammingLanguage__PHP = 'Programming Language :: PHP'
ProgrammingLanguage__PL_SQL = 'Programming Language :: PL/SQL'
ProgrammingLanguage__PROGRESS = 'Programming Language :: PROGRESS'
ProgrammingLanguage__Pascal = 'Programming Language :: Pascal'
ProgrammingLanguage__Perl = 'Programming Language :: Perl'
ProgrammingLanguage__Pike = 'Programming Language :: Pike'
ProgrammingLanguage__Pliant = 'Programming Language :: Pliant'
ProgrammingLanguage__Prolog = 'Programming Language :: Prolog'
ProgrammingLanguage__Python = 'Programming Language :: Python'
ProgrammingLanguage__Python__2 = 'Programming Language :: Python :: 2'
ProgrammingLanguage__Python__2__Only = 'Programming Language :: Python :: 2 :: Only'
ProgrammingLanguage__Python__23 = 'Programming Language :: Python :: 2.3'
ProgrammingLanguage__Python__24 = 'Programming Language :: Python :: 2.4'
ProgrammingLanguage__Python__25 = 'Programming Language :: Python :: 2.5'
ProgrammingLanguage__Python__26 = 'Programming Language :: Python :: 2.6'
ProgrammingLanguage__Python__27 = 'Programming Language :: Python :: 2.7'
ProgrammingLanguage__Python__3 = 'Programming Language :: Python :: 3'
ProgrammingLanguage__Python__3__Only = 'Programming Language :: Python :: 3 :: Only'
ProgrammingLanguage__Python__30 = 'Programming Language :: Python :: 3.0'
ProgrammingLanguage__Python__31 = 'Programming Language :: Python :: 3.1'
ProgrammingLanguage__Python__32 = 'Programming Language :: Python :: 3.2'
ProgrammingLanguage__Python__33 = 'Programming Language :: Python :: 3.3'
ProgrammingLanguage__Python__34 = 'Programming Language :: Python :: 3.4'
ProgrammingLanguage__Python__35 = 'Programming Language :: Python :: 3.5'
ProgrammingLanguage__Python__36 = 'Programming Language :: Python :: 3.6'
ProgrammingLanguage__Python__37 = 'Programming Language :: Python :: 3.7'
ProgrammingLanguage__Python__38 = 'Programming Language :: Python :: 3.8'
ProgrammingLanguage__Python__39 = 'Programming Language :: Python :: 3.9'
ProgrammingLanguage__Python__310 = 'Programming Language :: Python :: 3.10'
ProgrammingLanguage__Python__311 = 'Programming Language :: Python :: 3.11'
ProgrammingLanguage__Python__312 = 'Programming Language :: Python :: 3.12'
ProgrammingLanguage__Python__313 = 'Programming Language :: Python :: 3.13'
ProgrammingLanguage__Python__314 = 'Programming Language :: Python :: 3.14'
ProgrammingLanguage__Python__Implementation = 'Programming Language :: Python :: Implementation'
ProgrammingLanguage__Python__Implementation__CPython = 'Programming Language :: Python :: Implementation :: CPython'
ProgrammingLanguage__Python__Implementation__IronPython = \
    'Programming Language :: Python :: Implementation :: IronPython'
ProgrammingLanguage__Python__Implementation__Jython = 'Programming Language :: Python :: Implementation :: Jython'
ProgrammingLanguage__Python__Implementation__MicroPython = \
    'Programming Language :: Python :: Implementation :: MicroPython'
ProgrammingLanguage__Python__Implementation__PyPy = 'Programming Language :: Python :: Implementation :: PyPy'
ProgrammingLanguage__Python__Implementation__Stackless = \
    'Programming Language :: Python :: Implementation :: Stackless'
ProgrammingLanguage__R = 'Programming Language :: R'
ProgrammingLanguage__REBOL = 'Programming Language :: REBOL'
ProgrammingLanguage__Rexx = 'Programming Language :: Rexx'
ProgrammingLanguage__Ruby = 'Programming Language :: Ruby'
ProgrammingLanguage__Rust = 'Programming Language :: Rust'
ProgrammingLanguage__SQL = 'Programming Language :: SQL'
ProgrammingLanguage__Scheme = 'Programming Language :: Scheme'
ProgrammingLanguage__Simula = 'Programming Language :: Simula'
ProgrammingLanguage__Smalltalk = 'Programming Language :: Smalltalk'
ProgrammingLanguage__Tcl = 'Programming Language :: Tcl'
ProgrammingLanguage__UnixShell = 'Programming Language :: Unix Shell'
ProgrammingLanguage__VisualBasic = 'Programming Language :: Visual Basic'
ProgrammingLanguage__XBasic = 'Programming Language :: XBasic'
ProgrammingLanguage__YACC = 'Programming Language :: YACC'
ProgrammingLanguage__Zope = 'Programming Language :: Zope'
Topic__AdaptiveTechnologies = 'Topic :: Adaptive Technologies'
Topic__ArtisticSoftware = 'Topic :: Artistic Software'
Topic__Communications = 'Topic :: Communications'
Topic__Communications__BBS = 'Topic :: Communications :: BBS'
Topic__Communications__Chat = 'Topic :: Communications :: Chat'
Topic__Communications__Chat__ICQ = 'Topic :: Communications :: Chat :: ICQ'
Topic__Communications__Chat__InternetRelayChat = 'Topic :: Communications :: Chat :: Internet Relay Chat'
Topic__Communications__Chat__UnixTalk = 'Topic :: Communications :: Chat :: Unix Talk'
Topic__Communications__Conferencing = 'Topic :: Communications :: Conferencing'
Topic__Communications__Email = 'Topic :: Communications :: Email'
Topic__Communications__Email__AddressBook = 'Topic :: Communications :: Email :: Address Book'
Topic__Communications__Email__EmailClients_MUA_ = 'Topic :: Communications :: Email :: Email Clients (MUA)'
Topic__Communications__Email__Filters = 'Topic :: Communications :: Email :: Filters'
Topic__Communications__Email__MailTransportAgents = 'Topic :: Communications :: Email :: Mail Transport Agents'
Topic__Communications__Email__MailingListServers = 'Topic :: Communications :: Email :: Mailing List Servers'
Topic__Communications__Email__Post_Office = 'Topic :: Communications :: Email :: Post-Office'
Topic__Communications__Email__Post_Office__IMAP = 'Topic :: Communications :: Email :: Post-Office :: IMAP'
Topic__Communications__Email__Post_Office__POP3 = 'Topic :: Communications :: Email :: Post-Office :: POP3'
Topic__Communications__FIDO = 'Topic :: Communications :: FIDO'
Topic__Communications__Fax = 'Topic :: Communications :: Fax'
Topic__Communications__FileSharing = 'Topic :: Communications :: File Sharing'
Topic__Communications__FileSharing__Gnutella = 'Topic :: Communications :: File Sharing :: Gnutella'
Topic__Communications__FileSharing__Napster = 'Topic :: Communications :: File Sharing :: Napster'
Topic__Communications__HamRadio = 'Topic :: Communications :: Ham Radio'
Topic__Communications__InternetPhone = 'Topic :: Communications :: Internet Phone'
Topic__Communications__Telephony = 'Topic :: Communications :: Telephony'
Topic__Communications__UsenetNews = 'Topic :: Communications :: Usenet News'
Topic__Database = 'Topic :: Database'
Topic__Database__DatabaseEngines_Servers = 'Topic :: Database :: Database Engines/Servers'
Topic__Database__Front_Ends = 'Topic :: Database :: Front-Ends'
Topic__DesktopEnvironment = 'Topic :: Desktop Environment'
Topic__DesktopEnvironment__FileManagers = 'Topic :: Desktop Environment :: File Managers'
Topic__DesktopEnvironment__GNUstep = 'Topic :: Desktop Environment :: GNUstep'
Topic__DesktopEnvironment__Gnome = 'Topic :: Desktop Environment :: Gnome'
Topic__DesktopEnvironment__KDesktopEnvironment_KDE_ = 'Topic :: Desktop Environment :: K Desktop Environment (KDE)'
Topic__DesktopEnvironment__KDesktopEnvironment_KDE___Themes = \
    'Topic :: Desktop Environment :: K Desktop Environment (KDE) :: Themes'
Topic__DesktopEnvironment__PicoGUI = 'Topic :: Desktop Environment :: PicoGUI'
Topic__DesktopEnvironment__PicoGUI__Applications = 'Topic :: Desktop Environment :: PicoGUI :: Applications'
Topic__DesktopEnvironment__PicoGUI__Themes = 'Topic :: Desktop Environment :: PicoGUI :: Themes'
Topic__DesktopEnvironment__ScreenSavers = 'Topic :: Desktop Environment :: Screen Savers'
Topic__DesktopEnvironment__WindowManagers = 'Topic :: Desktop Environment :: Window Managers'
Topic__DesktopEnvironment__WindowManagers__Afterstep = 'Topic :: Desktop Environment :: Window Managers :: Afterstep'
Topic__DesktopEnvironment__WindowManagers__Afterstep__Themes = \
    'Topic :: Desktop Environment :: Window Managers :: Afterstep :: Themes'
Topic__DesktopEnvironment__WindowManagers__Applets = 'Topic :: Desktop Environment :: Window Managers :: Applets'
Topic__DesktopEnvironment__WindowManagers__Blackbox = 'Topic :: Desktop Environment :: Window Managers :: Blackbox'
Topic__DesktopEnvironment__WindowManagers__Blackbox__Themes = \
    'Topic :: Desktop Environment :: Window Managers :: Blackbox :: Themes'
Topic__DesktopEnvironment__WindowManagers__CTWM = 'Topic :: Desktop Environment :: Window Managers :: CTWM'
Topic__DesktopEnvironment__WindowManagers__CTWM__Themes = \
    'Topic :: Desktop Environment :: Window Managers :: CTWM :: Themes'
Topic__DesktopEnvironment__WindowManagers__Enlightenment = \
    'Topic :: Desktop Environment :: Window Managers :: Enlightenment'
Topic__DesktopEnvironment__WindowManagers__Enlightenment__Epplets = \
    'Topic :: Desktop Environment :: Window Managers :: Enlightenment :: Epplets'
Topic__DesktopEnvironment__WindowManagers__Enlightenment__ThemesDR15 = \
    'Topic :: Desktop Environment :: Window Managers :: Enlightenment :: Themes DR15'
Topic__DesktopEnvironment__WindowManagers__Enlightenment__ThemesDR16 = \
    'Topic :: Desktop Environment :: Window Managers :: Enlightenment :: Themes DR16'
Topic__DesktopEnvironment__WindowManagers__Enlightenment__ThemesDR17 = \
    'Topic :: Desktop Environment :: Window Managers :: Enlightenment :: Themes DR17'
Topic__DesktopEnvironment__WindowManagers__FVWM = 'Topic :: Desktop Environment :: Window Managers :: FVWM'
Topic__DesktopEnvironment__WindowManagers__FVWM__Themes = \
    'Topic :: Desktop Environment :: Window Managers :: FVWM :: Themes'
Topic__DesktopEnvironment__WindowManagers__Fluxbox = 'Topic :: Desktop Environment :: Window Managers :: Fluxbox'
Topic__DesktopEnvironment__WindowManagers__Fluxbox__Themes = \
    'Topic :: Desktop Environment :: Window Managers :: Fluxbox :: Themes'
Topic__DesktopEnvironment__WindowManagers__IceWM = 'Topic :: Desktop Environment :: Window Managers :: IceWM'
Topic__DesktopEnvironment__WindowManagers__IceWM__Themes = \
    'Topic :: Desktop Environment :: Window Managers :: IceWM :: Themes'
Topic__DesktopEnvironment__WindowManagers__MetaCity = 'Topic :: Desktop Environment :: Window Managers :: MetaCity'
Topic__DesktopEnvironment__WindowManagers__MetaCity__Themes = \
    'Topic :: Desktop Environment :: Window Managers :: MetaCity :: Themes'
Topic__DesktopEnvironment__WindowManagers__Oroborus = 'Topic :: Desktop Environment :: Window Managers :: Oroborus'
Topic__DesktopEnvironment__WindowManagers__Oroborus__Themes = \
    'Topic :: Desktop Environment :: Window Managers :: Oroborus :: Themes'
Topic__DesktopEnvironment__WindowManagers__Sawfish = 'Topic :: Desktop Environment :: Window Managers :: Sawfish'
Topic__DesktopEnvironment__WindowManagers__Sawfish__Themes030 = \
    'Topic :: Desktop Environment :: Window Managers :: Sawfish :: Themes 0.30'
Topic__DesktopEnvironment__WindowManagers__Sawfish__Themespre_030 = \
    'Topic :: Desktop Environment :: Window Managers :: Sawfish :: Themes pre-0.30'
Topic__DesktopEnvironment__WindowManagers__Waimea = 'Topic :: Desktop Environment :: Window Managers :: Waimea'
Topic__DesktopEnvironment__WindowManagers__Waimea__Themes = \
    'Topic :: Desktop Environment :: Window Managers :: Waimea :: Themes'
Topic__DesktopEnvironment__WindowManagers__WindowMaker = \
    'Topic :: Desktop Environment :: Window Managers :: Window Maker'
Topic__DesktopEnvironment__WindowManagers__WindowMaker__Applets = \
    'Topic :: Desktop Environment :: Window Managers :: Window Maker :: Applets'
Topic__DesktopEnvironment__WindowManagers__WindowMaker__Themes = \
    'Topic :: Desktop Environment :: Window Managers :: Window Maker :: Themes'
Topic__DesktopEnvironment__WindowManagers__XFCE = 'Topic :: Desktop Environment :: Window Managers :: XFCE'
Topic__DesktopEnvironment__WindowManagers__XFCE__Themes = \
    'Topic :: Desktop Environment :: Window Managers :: XFCE :: Themes'
Topic__Documentation = 'Topic :: Documentation'
Topic__Documentation__Sphinx = 'Topic :: Documentation :: Sphinx'
Topic__Education = 'Topic :: Education'
Topic__Education__ComputerAidedInstruction_CAI_ = 'Topic :: Education :: Computer Aided Instruction (CAI)'
Topic__Education__Testing = 'Topic :: Education :: Testing'
Topic__FileFormats = 'Topic :: File Formats'
Topic__FileFormats__JSON = 'Topic :: File Formats :: JSON'
Topic__FileFormats__JSON__JSONSchema = 'Topic :: File Formats :: JSON :: JSON Schema'
Topic__Games_Entertainment = 'Topic :: Games/Entertainment'
Topic__Games_Entertainment__Arcade = 'Topic :: Games/Entertainment :: Arcade'
Topic__Games_Entertainment__BoardGames = 'Topic :: Games/Entertainment :: Board Games'
Topic__Games_Entertainment__FirstPersonShooters = 'Topic :: Games/Entertainment :: First Person Shooters'
Topic__Games_Entertainment__FortuneCookies = 'Topic :: Games/Entertainment :: Fortune Cookies'
Topic__Games_Entertainment__Multi_UserDungeons_MUD_ = 'Topic :: Games/Entertainment :: Multi-User Dungeons (MUD)'
Topic__Games_Entertainment__PuzzleGames = 'Topic :: Games/Entertainment :: Puzzle Games'
Topic__Games_Entertainment__RealTimeStrategy = 'Topic :: Games/Entertainment :: Real Time Strategy'
Topic__Games_Entertainment__Role_Playing = 'Topic :: Games/Entertainment :: Role-Playing'
Topic__Games_Entertainment__Side_Scrolling_ArcadeGames = 'Topic :: Games/Entertainment :: Side-Scrolling/Arcade Games'
Topic__Games_Entertainment__Simulation = 'Topic :: Games/Entertainment :: Simulation'
Topic__Games_Entertainment__TurnBasedStrategy = 'Topic :: Games/Entertainment :: Turn Based Strategy'
Topic__HomeAutomation = 'Topic :: Home Automation'
Topic__Internet = 'Topic :: Internet'
Topic__Internet__FileTransferProtocol_FTP_ = 'Topic :: Internet :: File Transfer Protocol (FTP)'
Topic__Internet__Finger = 'Topic :: Internet :: Finger'
Topic__Internet__LogAnalysis = 'Topic :: Internet :: Log Analysis'
Topic__Internet__NameService_DNS_ = 'Topic :: Internet :: Name Service (DNS)'
Topic__Internet__ProxyServers = 'Topic :: Internet :: Proxy Servers'
Topic__Internet__WAP = 'Topic :: Internet :: WAP'
Topic__Internet__WWW_HTTP = 'Topic :: Internet :: WWW/HTTP'
Topic__Internet__WWW_HTTP__Browsers = 'Topic :: Internet :: WWW/HTTP :: Browsers'
Topic__Internet__WWW_HTTP__DynamicContent = 'Topic :: Internet :: WWW/HTTP :: Dynamic Content'
Topic__Internet__WWW_HTTP__DynamicContent__CGITools_Libraries = \
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content :: CGI Tools/Libraries'
Topic__Internet__WWW_HTTP__DynamicContent__ContentManagementSystem = \
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content :: Content Management System'
Topic__Internet__WWW_HTTP__DynamicContent__MessageBoards = \
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content :: Message Boards'
Topic__Internet__WWW_HTTP__DynamicContent__News_Diary = \
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content :: News/Diary'
Topic__Internet__WWW_HTTP__DynamicContent__PageCounters = \
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content :: Page Counters'
Topic__Internet__WWW_HTTP__DynamicContent__Wiki = 'Topic :: Internet :: WWW/HTTP :: Dynamic Content :: Wiki'
Topic__Internet__WWW_HTTP__HTTPServers = 'Topic :: Internet :: WWW/HTTP :: HTTP Servers'
Topic__Internet__WWW_HTTP__Indexing_Search = 'Topic :: Internet :: WWW/HTTP :: Indexing/Search'
Topic__Internet__WWW_HTTP__Session = 'Topic :: Internet :: WWW/HTTP :: Session'
Topic__Internet__WWW_HTTP__SiteManagement = 'Topic :: Internet :: WWW/HTTP :: Site Management'
Topic__Internet__WWW_HTTP__SiteManagement__LinkChecking = \
    'Topic :: Internet :: WWW/HTTP :: Site Management :: Link Checking'
Topic__Internet__WWW_HTTP__WSGI = 'Topic :: Internet :: WWW/HTTP :: WSGI'
Topic__Internet__WWW_HTTP__WSGI__Application = 'Topic :: Internet :: WWW/HTTP :: WSGI :: Application'
Topic__Internet__WWW_HTTP__WSGI__Middleware = 'Topic :: Internet :: WWW/HTTP :: WSGI :: Middleware'
Topic__Internet__WWW_HTTP__WSGI__Server = 'Topic :: Internet :: WWW/HTTP :: WSGI :: Server'
Topic__Internet__XMPP = 'Topic :: Internet :: XMPP'
Topic__Internet__Z3950 = 'Topic :: Internet :: Z39.50'
Topic__Multimedia = 'Topic :: Multimedia'
Topic__Multimedia__Graphics = 'Topic :: Multimedia :: Graphics'
Topic__Multimedia__Graphics__3DModeling = 'Topic :: Multimedia :: Graphics :: 3D Modeling'
Topic__Multimedia__Graphics__3DRendering = 'Topic :: Multimedia :: Graphics :: 3D Rendering'
Topic__Multimedia__Graphics__Capture = 'Topic :: Multimedia :: Graphics :: Capture'
Topic__Multimedia__Graphics__Capture__DigitalCamera = 'Topic :: Multimedia :: Graphics :: Capture :: Digital Camera'
Topic__Multimedia__Graphics__Capture__Scanners = 'Topic :: Multimedia :: Graphics :: Capture :: Scanners'
Topic__Multimedia__Graphics__Capture__ScreenCapture = 'Topic :: Multimedia :: Graphics :: Capture :: Screen Capture'
Topic__Multimedia__Graphics__Editors = 'Topic :: Multimedia :: Graphics :: Editors'
Topic__Multimedia__Graphics__Editors__Raster_Based = 'Topic :: Multimedia :: Graphics :: Editors :: Raster-Based'
Topic__Multimedia__Graphics__Editors__Vector_Based = 'Topic :: Multimedia :: Graphics :: Editors :: Vector-Based'
Topic__Multimedia__Graphics__GraphicsConversion = 'Topic :: Multimedia :: Graphics :: Graphics Conversion'
Topic__Multimedia__Graphics__Presentation = 'Topic :: Multimedia :: Graphics :: Presentation'
Topic__Multimedia__Graphics__Viewers = 'Topic :: Multimedia :: Graphics :: Viewers'
Topic__Multimedia__Sound_Audio = 'Topic :: Multimedia :: Sound/Audio'
Topic__Multimedia__Sound_Audio__Analysis = 'Topic :: Multimedia :: Sound/Audio :: Analysis'
Topic__Multimedia__Sound_Audio__CDAudio = 'Topic :: Multimedia :: Sound/Audio :: CD Audio'
Topic__Multimedia__Sound_Audio__CDAudio__CDPlaying = 'Topic :: Multimedia :: Sound/Audio :: CD Audio :: CD Playing'
Topic__Multimedia__Sound_Audio__CDAudio__CDRipping = 'Topic :: Multimedia :: Sound/Audio :: CD Audio :: CD Ripping'
Topic__Multimedia__Sound_Audio__CDAudio__CDWriting = 'Topic :: Multimedia :: Sound/Audio :: CD Audio :: CD Writing'
Topic__Multimedia__Sound_Audio__Capture_Recording = 'Topic :: Multimedia :: Sound/Audio :: Capture/Recording'
Topic__Multimedia__Sound_Audio__Conversion = 'Topic :: Multimedia :: Sound/Audio :: Conversion'
Topic__Multimedia__Sound_Audio__Editors = 'Topic :: Multimedia :: Sound/Audio :: Editors'
Topic__Multimedia__Sound_Audio__MIDI = 'Topic :: Multimedia :: Sound/Audio :: MIDI'
Topic__Multimedia__Sound_Audio__Mixers = 'Topic :: Multimedia :: Sound/Audio :: Mixers'
Topic__Multimedia__Sound_Audio__Players = 'Topic :: Multimedia :: Sound/Audio :: Players'
Topic__Multimedia__Sound_Audio__Players__MP3 = 'Topic :: Multimedia :: Sound/Audio :: Players :: MP3'
Topic__Multimedia__Sound_Audio__SoundSynthesis = 'Topic :: Multimedia :: Sound/Audio :: Sound Synthesis'
Topic__Multimedia__Sound_Audio__Speech = 'Topic :: Multimedia :: Sound/Audio :: Speech'
Topic__Multimedia__Video = 'Topic :: Multimedia :: Video'
Topic__Multimedia__Video__Capture = 'Topic :: Multimedia :: Video :: Capture'
Topic__Multimedia__Video__Conversion = 'Topic :: Multimedia :: Video :: Conversion'
Topic__Multimedia__Video__Display = 'Topic :: Multimedia :: Video :: Display'
Topic__Multimedia__Video__Non_LinearEditor = 'Topic :: Multimedia :: Video :: Non-Linear Editor'
Topic__Office_Business = 'Topic :: Office/Business'
Topic__Office_Business__Financial = 'Topic :: Office/Business :: Financial'
Topic__Office_Business__Financial__Accounting = 'Topic :: Office/Business :: Financial :: Accounting'
Topic__Office_Business__Financial__Investment = 'Topic :: Office/Business :: Financial :: Investment'
Topic__Office_Business__Financial__Point_Of_Sale = 'Topic :: Office/Business :: Financial :: Point-Of-Sale'
Topic__Office_Business__Financial__Spreadsheet = 'Topic :: Office/Business :: Financial :: Spreadsheet'
Topic__Office_Business__Groupware = 'Topic :: Office/Business :: Groupware'
Topic__Office_Business__News_Diary = 'Topic :: Office/Business :: News/Diary'
Topic__Office_Business__OfficeSuites = 'Topic :: Office/Business :: Office Suites'
Topic__Office_Business__Scheduling = 'Topic :: Office/Business :: Scheduling'
Topic__Other_NonlistedTopic = 'Topic :: Other/Nonlisted Topic'
Topic__Printing = 'Topic :: Printing'
Topic__Religion = 'Topic :: Religion'
Topic__Scientific_Engineering = 'Topic :: Scientific/Engineering'
Topic__Scientific_Engineering__ArtificialIntelligence = 'Topic :: Scientific/Engineering :: Artificial Intelligence'
Topic__Scientific_Engineering__ArtificialLife = 'Topic :: Scientific/Engineering :: Artificial Life'
Topic__Scientific_Engineering__Astronomy = 'Topic :: Scientific/Engineering :: Astronomy'
Topic__Scientific_Engineering__AtmosphericScience = 'Topic :: Scientific/Engineering :: Atmospheric Science'
Topic__Scientific_Engineering__Bio_Informatics = 'Topic :: Scientific/Engineering :: Bio-Informatics'
Topic__Scientific_Engineering__Chemistry = 'Topic :: Scientific/Engineering :: Chemistry'
Topic__Scientific_Engineering__ElectronicDesignAutomation_EDA_ = \
    'Topic :: Scientific/Engineering :: Electronic Design Automation (EDA)'
Topic__Scientific_Engineering__GIS = 'Topic :: Scientific/Engineering :: GIS'
Topic__Scientific_Engineering__HumanMachineInterfaces = 'Topic :: Scientific/Engineering :: Human Machine Interfaces'
Topic__Scientific_Engineering__Hydrology = 'Topic :: Scientific/Engineering :: Hydrology'
Topic__Scientific_Engineering__ImageProcessing = 'Topic :: Scientific/Engineering :: Image Processing'
Topic__Scientific_Engineering__ImageRecognition = 'Topic :: Scientific/Engineering :: Image Recognition'
Topic__Scientific_Engineering__InformationAnalysis = 'Topic :: Scientific/Engineering :: Information Analysis'
Topic__Scientific_Engineering__InterfaceEngine_ProtocolTranslator = \
    'Topic :: Scientific/Engineering :: Interface Engine/Protocol Translator'
Topic__Scientific_Engineering__Mathematics = 'Topic :: Scientific/Engineering :: Mathematics'
Topic__Scientific_Engineering__MedicalScienceApps = 'Topic :: Scientific/Engineering :: Medical Science Apps.'
Topic__Scientific_Engineering__Oceanography = 'Topic :: Scientific/Engineering :: Oceanography'
Topic__Scientific_Engineering__Physics = 'Topic :: Scientific/Engineering :: Physics'
Topic__Scientific_Engineering__QuantumComputing = 'Topic :: Scientific/Engineering :: Quantum Computing'
Topic__Scientific_Engineering__Visualization = 'Topic :: Scientific/Engineering :: Visualization'
Topic__Security = 'Topic :: Security'
Topic__Security__Cryptography = 'Topic :: Security :: Cryptography'
Topic__Sociology = 'Topic :: Sociology'
Topic__Sociology__Genealogy = 'Topic :: Sociology :: Genealogy'
Topic__Sociology__History = 'Topic :: Sociology :: History'
Topic__SoftwareDevelopment = 'Topic :: Software Development'
Topic__SoftwareDevelopment__Assemblers = 'Topic :: Software Development :: Assemblers'
Topic__SoftwareDevelopment__BugTracking = 'Topic :: Software Development :: Bug Tracking'
Topic__SoftwareDevelopment__BuildTools = 'Topic :: Software Development :: Build Tools'
Topic__SoftwareDevelopment__CodeGenerators = 'Topic :: Software Development :: Code Generators'
Topic__SoftwareDevelopment__Compilers = 'Topic :: Software Development :: Compilers'
Topic__SoftwareDevelopment__Debuggers = 'Topic :: Software Development :: Debuggers'
Topic__SoftwareDevelopment__Disassemblers = 'Topic :: Software Development :: Disassemblers'
Topic__SoftwareDevelopment__Documentation = 'Topic :: Software Development :: Documentation'
Topic__SoftwareDevelopment__EmbeddedSystems = 'Topic :: Software Development :: Embedded Systems'
Topic__SoftwareDevelopment__EmbeddedSystems__ControllerAreaNetwork_CAN_ = \
    'Topic :: Software Development :: Embedded Systems :: Controller Area Network (CAN)'
Topic__SoftwareDevelopment__EmbeddedSystems__ControllerAreaNetwork_CAN___CANopen = \
    'Topic :: Software Development :: Embedded Systems :: Controller Area Network (CAN) :: CANopen'
Topic__SoftwareDevelopment__EmbeddedSystems__ControllerAreaNetwork_CAN___J1939 = \
    'Topic :: Software Development :: Embedded Systems :: Controller Area Network (CAN) :: J1939'
Topic__SoftwareDevelopment__Internationalization = 'Topic :: Software Development :: Internationalization'
Topic__SoftwareDevelopment__Interpreters = 'Topic :: Software Development :: Interpreters'
Topic__SoftwareDevelopment__Libraries = 'Topic :: Software Development :: Libraries'
Topic__SoftwareDevelopment__Libraries__ApplicationFrameworks = \
    'Topic :: Software Development :: Libraries :: Application Frameworks'
Topic__SoftwareDevelopment__Libraries__JavaLibraries = 'Topic :: Software Development :: Libraries :: Java Libraries'
Topic__SoftwareDevelopment__Libraries__PHPClasses = 'Topic :: Software Development :: Libraries :: PHP Classes'
Topic__SoftwareDevelopment__Libraries__PerlModules = 'Topic :: Software Development :: Libraries :: Perl Modules'
Topic__SoftwareDevelopment__Libraries__PikeModules = 'Topic :: Software Development :: Libraries :: Pike Modules'
Topic__SoftwareDevelopment__Libraries__PythonModules = 'Topic :: Software Development :: Libraries :: Python Modules'
Topic__SoftwareDevelopment__Libraries__RubyModules = 'Topic :: Software Development :: Libraries :: Ruby Modules'
Topic__SoftwareDevelopment__Libraries__TclExtensions = 'Topic :: Software Development :: Libraries :: Tcl Extensions'
Topic__SoftwareDevelopment__Libraries__pygame = 'Topic :: Software Development :: Libraries :: pygame'
Topic__SoftwareDevelopment__Localization = 'Topic :: Software Development :: Localization'
Topic__SoftwareDevelopment__ObjectBrokering = 'Topic :: Software Development :: Object Brokering'
Topic__SoftwareDevelopment__ObjectBrokering__CORBA = 'Topic :: Software Development :: Object Brokering :: CORBA'
Topic__SoftwareDevelopment__Pre_processors = 'Topic :: Software Development :: Pre-processors'
Topic__SoftwareDevelopment__QualityAssurance = 'Topic :: Software Development :: Quality Assurance'
Topic__SoftwareDevelopment__Testing = 'Topic :: Software Development :: Testing'
Topic__SoftwareDevelopment__Testing__Acceptance = 'Topic :: Software Development :: Testing :: Acceptance'
Topic__SoftwareDevelopment__Testing__BDD = 'Topic :: Software Development :: Testing :: BDD'
Topic__SoftwareDevelopment__Testing__Mocking = 'Topic :: Software Development :: Testing :: Mocking'
Topic__SoftwareDevelopment__Testing__TrafficGeneration = \
    'Topic :: Software Development :: Testing :: Traffic Generation'
Topic__SoftwareDevelopment__Testing__Unit = 'Topic :: Software Development :: Testing :: Unit'
Topic__SoftwareDevelopment__UserInterfaces = 'Topic :: Software Development :: User Interfaces'
Topic__SoftwareDevelopment__VersionControl = 'Topic :: Software Development :: Version Control'
Topic__SoftwareDevelopment__VersionControl__Bazaar = 'Topic :: Software Development :: Version Control :: Bazaar'
Topic__SoftwareDevelopment__VersionControl__CVS = 'Topic :: Software Development :: Version Control :: CVS'
Topic__SoftwareDevelopment__VersionControl__Git = 'Topic :: Software Development :: Version Control :: Git'
Topic__SoftwareDevelopment__VersionControl__Mercurial = \
    'Topic :: Software Development :: Version Control :: Mercurial'
Topic__SoftwareDevelopment__VersionControl__RCS = 'Topic :: Software Development :: Version Control :: RCS'
Topic__SoftwareDevelopment__VersionControl__SCCS = 'Topic :: Software Development :: Version Control :: SCCS'
Topic__SoftwareDevelopment__WidgetSets = 'Topic :: Software Development :: Widget Sets'
Topic__System = 'Topic :: System'
Topic__System__Archiving = 'Topic :: System :: Archiving'
Topic__System__Archiving__Backup = 'Topic :: System :: Archiving :: Backup'
Topic__System__Archiving__Compression = 'Topic :: System :: Archiving :: Compression'
Topic__System__Archiving__Mirroring = 'Topic :: System :: Archiving :: Mirroring'
Topic__System__Archiving__Packaging = 'Topic :: System :: Archiving :: Packaging'
Topic__System__Benchmark = 'Topic :: System :: Benchmark'
Topic__System__Boot = 'Topic :: System :: Boot'
Topic__System__Boot__Init = 'Topic :: System :: Boot :: Init'
Topic__System__Clustering = 'Topic :: System :: Clustering'
Topic__System__ConsoleFonts = 'Topic :: System :: Console Fonts'
Topic__System__DistributedComputing = 'Topic :: System :: Distributed Computing'
Topic__System__Emulators = 'Topic :: System :: Emulators'
Topic__System__Filesystems = 'Topic :: System :: Filesystems'
Topic__System__Hardware = 'Topic :: System :: Hardware'
Topic__System__Hardware__HardwareDrivers = 'Topic :: System :: Hardware :: Hardware Drivers'
Topic__System__Hardware__Mainframes = 'Topic :: System :: Hardware :: Mainframes'
Topic__System__Hardware__SymmetricMulti_processing = 'Topic :: System :: Hardware :: Symmetric Multi-processing'
Topic__System__Hardware__UniversalSerialBus_USB_ = 'Topic :: System :: Hardware :: Universal Serial Bus (USB)'
Topic__System__Hardware__UniversalSerialBus_USB___Audio = \
    'Topic :: System :: Hardware :: Universal Serial Bus (USB) :: Audio'
Topic__System__Hardware__UniversalSerialBus_USB___Audio_Video_AV_ = \
    'Topic :: System :: Hardware :: Universal Serial Bus (USB) :: Audio/Video (AV)'
Topic__System__Hardware__UniversalSerialBus_USB___CommunicationsDeviceClass_CDC_ = \
    'Topic :: System :: Hardware :: Universal Serial Bus (USB) :: Communications Device Class (CDC)'
Topic__System__Hardware__UniversalSerialBus_USB___DiagnosticDevice = \
    'Topic :: System :: Hardware :: Universal Serial Bus (USB) :: Diagnostic Device'
Topic__System__Hardware__UniversalSerialBus_USB___Hub = \
    'Topic :: System :: Hardware :: Universal Serial Bus (USB) :: Hub'
Topic__System__Hardware__UniversalSerialBus_USB___HumanInterfaceDevice_HID_ = \
    'Topic :: System :: Hardware :: Universal Serial Bus (USB) :: Human Interface Device (HID)'
Topic__System__Hardware__UniversalSerialBus_USB___MassStorage = \
    'Topic :: System :: Hardware :: Universal Serial Bus (USB) :: Mass Storage'
Topic__System__Hardware__UniversalSerialBus_USB___Miscellaneous = \
    'Topic :: System :: Hardware :: Universal Serial Bus (USB) :: Miscellaneous'
Topic__System__Hardware__UniversalSerialBus_USB___Printer = \
    'Topic :: System :: Hardware :: Universal Serial Bus (USB) :: Printer'
Topic__System__Hardware__UniversalSerialBus_USB___SmartCard = \
    'Topic :: System :: Hardware :: Universal Serial Bus (USB) :: Smart Card'
Topic__System__Hardware__UniversalSerialBus_USB___Vendor = \
    'Topic :: System :: Hardware :: Universal Serial Bus (USB) :: Vendor'
Topic__System__Hardware__UniversalSerialBus_USB___Video_UVC_ = \
    'Topic :: System :: Hardware :: Universal Serial Bus (USB) :: Video (UVC)'
Topic__System__Hardware__UniversalSerialBus_USB___WirelessController = \
    'Topic :: System :: Hardware :: Universal Serial Bus (USB) :: Wireless Controller'
Topic__System__Installation_Setup = 'Topic :: System :: Installation/Setup'
Topic__System__Logging = 'Topic :: System :: Logging'
Topic__System__Monitoring = 'Topic :: System :: Monitoring'
Topic__System__Networking = 'Topic :: System :: Networking'
Topic__System__Networking__Firewalls = 'Topic :: System :: Networking :: Firewalls'
Topic__System__Networking__Monitoring = 'Topic :: System :: Networking :: Monitoring'
Topic__System__Networking__Monitoring__HardwareWatchdog = \
    'Topic :: System :: Networking :: Monitoring :: Hardware Watchdog'
Topic__System__Networking__TimeSynchronization = 'Topic :: System :: Networking :: Time Synchronization'
Topic__System__OperatingSystem = 'Topic :: System :: Operating System'
Topic__System__OperatingSystemKernels = 'Topic :: System :: Operating System Kernels'
Topic__System__OperatingSystemKernels__BSD = 'Topic :: System :: Operating System Kernels :: BSD'
Topic__System__OperatingSystemKernels__GNUHurd = 'Topic :: System :: Operating System Kernels :: GNU Hurd'
Topic__System__OperatingSystemKernels__Linux = 'Topic :: System :: Operating System Kernels :: Linux'
Topic__System__Power_UPS_ = 'Topic :: System :: Power (UPS)'
Topic__System__RecoveryTools = 'Topic :: System :: Recovery Tools'
Topic__System__Shells = 'Topic :: System :: Shells'
Topic__System__SoftwareDistribution = 'Topic :: System :: Software Distribution'
Topic__System__SystemShells = 'Topic :: System :: System Shells'
Topic__System__SystemsAdministration = 'Topic :: System :: Systems Administration'
Topic__System__SystemsAdministration__Authentication_Directory = \
    'Topic :: System :: Systems Administration :: Authentication/Directory'
Topic__System__SystemsAdministration__Authentication_Directory__LDAP = \
    'Topic :: System :: Systems Administration :: Authentication/Directory :: LDAP'
Topic__System__SystemsAdministration__Authentication_Directory__NIS = \
    'Topic :: System :: Systems Administration :: Authentication/Directory :: NIS'
Topic__Terminals = 'Topic :: Terminals'
Topic__Terminals__Serial = 'Topic :: Terminals :: Serial'
Topic__Terminals__Telnet = 'Topic :: Terminals :: Telnet'
Topic__Terminals__TerminalEmulators_XTerminals = 'Topic :: Terminals :: Terminal Emulators/X Terminals'
Topic__TextEditors = 'Topic :: Text Editors'
Topic__TextEditors__Documentation = 'Topic :: Text Editors :: Documentation'
Topic__TextEditors__Emacs = 'Topic :: Text Editors :: Emacs'
Topic__TextEditors__IntegratedDevelopmentEnvironments_IDE_ = \
    'Topic :: Text Editors :: Integrated Development Environments (IDE)'
Topic__TextEditors__TextProcessing = 'Topic :: Text Editors :: Text Processing'
Topic__TextEditors__WordProcessors = 'Topic :: Text Editors :: Word Processors'
Topic__TextProcessing = 'Topic :: Text Processing'
Topic__TextProcessing__Filters = 'Topic :: Text Processing :: Filters'
Topic__TextProcessing__Fonts = 'Topic :: Text Processing :: Fonts'
Topic__TextProcessing__General = 'Topic :: Text Processing :: General'
Topic__TextProcessing__Indexing = 'Topic :: Text Processing :: Indexing'
Topic__TextProcessing__Linguistic = 'Topic :: Text Processing :: Linguistic'
Topic__TextProcessing__Markup = 'Topic :: Text Processing :: Markup'
Topic__TextProcessing__Markup__HTML = 'Topic :: Text Processing :: Markup :: HTML'
Topic__TextProcessing__Markup__LaTeX = 'Topic :: Text Processing :: Markup :: LaTeX'
Topic__TextProcessing__Markup__Markdown = 'Topic :: Text Processing :: Markup :: Markdown'
Topic__TextProcessing__Markup__SGML = 'Topic :: Text Processing :: Markup :: SGML'
Topic__TextProcessing__Markup__VRML = 'Topic :: Text Processing :: Markup :: VRML'
Topic__TextProcessing__Markup__XML = 'Topic :: Text Processing :: Markup :: XML'
Topic__TextProcessing__Markup__reStructuredText = 'Topic :: Text Processing :: Markup :: reStructuredText'
Topic__Utilities = 'Topic :: Utilities'
Typing__StubsOnly = 'Typing :: Stubs Only'
Typing__Typed = 'Typing :: Typed'
